@@ -45,7 +45,11 @@ def set_value(dut, base_name, mapping, value, separator):
             set_value(dut, base_name + separator + str(sub_index),
                       mapping[sub_index], sub_value, separator)
     else:
-        getattr(dut, base_name) <= value
+        attribute = getattr(dut, base_name)
+        # Check that we're not trying to assign something to a bundle
+        # that isn't a list of dict.
+        assert not isinstance(attribute, Bundle)
+        attribute <= value
 
 
 def get_value(dut, base_name, mapping, separator):
